@@ -68,7 +68,7 @@ class BarChart(Chart):
             w = self.area.w * bar.w
             h = self.area.h * bar.h
 
-            if w < 1 or h < 1:
+            if (w < 1 or h < 1) and self.options.yvals.skipSmallValues:
                 return # don't draw when the bar is too small
 
             if self.options.stroke.shadow:
@@ -89,13 +89,19 @@ class BarChart(Chart):
                     cx.rectangle(x, y, w, h)
                     cx.stroke()
 
+            if bar.yerr:
+                self._renderError(cx, x, y, w, h, bar.yval, bar.yerr)
+
             # render yvals above/beside bars
             if self.options.yvals.show:
                 cx.save()
                 cx.set_font_size(self.options.yvals.fontSize)
                 cx.set_source_rgb(*hex2rgb(self.options.yvals.fontColor))
 
-                label = unicode(bar.yval)
+                if callable(self.options.yvals.renderer):
+                    label = unicode(self.options.yvals.renderer(bar))
+                else:
+                    label = unicode(bar.yval)
                 extents = cx.text_extents(label)
                 labelW = extents[2]
                 labelH = extents[3]
@@ -120,7 +126,12 @@ class VerticalBarChart(BarChart):
         super(VerticalBarChart, self)._updateChart()
         for i, (name, store) in enumerate(self.datasets):
             for item in store:
-                xval, yval = item
+                if len(item) == 3:
+                    xval, yval, yerr = item
+                else:
+                    xval, yval = item
+                    yerr = 0.0
+
                 x = (((xval - self.minxval) * self.xscale)
                     + self.barMargin + (i * self.barWidthForSet))
                 w = self.barWidthForSet
@@ -145,7 +156,9 @@ class VerticalBarChart(BarChart):
 
     def _renderYVal(self, cx, label, labelW, labelH, barX, barY, barW, barH):
         x = barX + (barW / 2.0) - (labelW / 2.0)
-        if self.options.yvals.inside:
+        if self.options.yvals.snapToOrigin:
+            y = barY + barH - 0.5 * labelH
+        elif self.options.yvals.inside:
             y = barY + (1.5 * labelH)
         else:
             y = barY - 0.5 * labelH
@@ -157,6 +170,26 @@ class VerticalBarChart(BarChart):
         cx.move_to(x, y)
         cx.show_text(label)
 
+    def _renderError(self, cx, barX, barY, barW, barH, value, error):
+        center = barX + (barW / 2.0)
+        errorWidth = max(barW * 0.1, 5.0)
+        left = center - errorWidth
+        right = center + errorWidth
+        errorSize = barH * error / value
+        top = barY + errorSize
+        bottom = barY - errorSize
+
+        cx.set_source_rgb(0, 0, 0)
+        cx.move_to(left, top)
+        cx.line_to(right, top)
+        cx.stroke()
+        cx.move_to(center, top)
+        cx.line_to(center, bottom)
+        cx.stroke()
+        cx.move_to(left, bottom)
+        cx.line_to(right, bottom)
+        cx.stroke()
+
 
 class HorizontalBarChart(BarChart):
 
@@ -166,7 +199,12 @@ class HorizontalBarChart(BarChart):
 
         for i, (name, store) in enumerate(self.datasets):
             for item in store:
-                xval, yval = item
+                if len(item) == 3:
+                    xval, yval, yerr = item
+                else:
+                    xval, yval = item
+                    yerr = 0.0
+
                 y = (((xval - self.minxval) * self.xscale)
                      + self.barMargin + (i * self.barWidthForSet))
                 h = self.barWidthForSet
@@ -175,7 +213,7 @@ class HorizontalBarChart(BarChart):
                     x = self.area.origin
                 else:
                     x = self.area.origin - w
-                rect = Rect(x, y, w, h, xval, yval, name)
+                rect = Rect(x, y, w, h, xval, yval, name, yerr)
 
                 if (0.0 <= rect.x <= 1.0) and (0.0 <= rect.y <= 1.0):
                     self.bars.append(rect)
@@ -197,6 +235,10 @@ class HorizontalBarChart(BarChart):
     def _getShadowRectangle(self, x, y, w, h):
         return (x, y-2, w+2, h+4)
 
+    def _renderXAxisLabel(self, cx, labelText):
+        labelText = self.options.axis.x.label
+        super(HorizontalBarChart, self)._renderYAxisLabel(cx, labelText)
+
     def _renderXAxis(self, cx):
         """Draws the horizontal line representing the X axis"""
         cx.new_path()
@@ -205,6 +247,10 @@ class HorizontalBarChart(BarChart):
         cx.close_path()
         cx.stroke()
 
+    def _renderYAxisLabel(self, cx, labelText):
+        labelText = self.options.axis.y.label
+        super(HorizontalBarChart, self)._renderXAxisLabel(cx, labelText)
+
     def _renderYAxis(self, cx):
         # draws the vertical line representing the Y axis
         cx.new_path()
@@ -217,7 +263,9 @@ class HorizontalBarChart(BarChart):
 
     def _renderYVal(self, cx, label, labelW, labelH, barX, barY, barW, barH):
         y = barY + (barH / 2.0) + (labelH / 2.0)
-        if self.options.yvals.inside:
+        if self.options.yvals.snapToOrigin:
+            x = barX + 2
+        elif self.options.yvals.inside:
             x = barX + barW - (1.2 * labelW)
         else:
             x = barX + barW + 0.2 * labelW
@@ -229,15 +277,36 @@ class HorizontalBarChart(BarChart):
         cx.move_to(x, y)
         cx.show_text(label)
 
+    def _renderError(self, cx, barX, barY, barW, barH, value, error):
+        center = barY + (barH / 2.0)
+        errorHeight = max(barH * 0.1, 5.0)
+        top = center + errorHeight
+        bottom = center - errorHeight
+        errorSize = barW * error / value
+        right = barX + barW + errorSize
+        left = barX + barW - errorSize
+
+        cx.set_source_rgb(0, 0, 0)
+        cx.move_to(left, top)
+        cx.line_to(left, bottom)
+        cx.stroke()
+        cx.move_to(left, center)
+        cx.line_to(right, center)
+        cx.stroke()
+        cx.move_to(right, top)
+        cx.line_to(right, bottom)
+        cx.stroke()
+
 
 class Rect(object):
 
-    def __init__(self, x, y, w, h, xval, yval, name):
+    def __init__(self, x, y, w, h, xval, yval, name, yerr=0.0):
         self.x, self.y, self.w, self.h = x, y, w, h
-        self.xval, self.yval = xval, yval
+        self.xval, self.yval, self.yerr = xval, yval, yerr
         self.name = name
 
     def __str__(self):
-        return ("<pycha.bar.Rect@(%.2f, %.2f) %.2fx%.2f (%.2f, %.2f) %s>"
-                % (self.x, self.y, self.w, self.h, self.xval, self.yval,
+        return ("<pycha.bar.Rect@(%.2f, %.2f) %.2fx%.2f (%.2f, %.2f, %.2f) %s>"
+                % (self.x, self.y, self.w, self.h,
+                   self.xval, self.yval, self.yerr,
                    self.name))
