@@ -265,8 +265,9 @@ class Chart(object):
             interval = self.options.axis.y.interval
             label = (divmod(self.minyval, interval)[0] + 1) * interval
             pos = 1.0 - (self.yscale * (label - self.minyval))
+            prec = self.options.axis.y.tickPrecision
             while 0.0 <= pos <= 1.0:
-                self.yticks.append((pos, label))
+                self.yticks.append((pos, round(label, prec)))
                 label += interval
                 pos = 1.0 - (self.yscale * (label - self.minyval))
 
@@ -452,6 +453,18 @@ class Chart(object):
 
         cx.show_text(label)
 
+    def _renderYAxisLabel(self, cx, labelText):
+        cx.save()
+        rotate = self.options.axis.y.rotate
+        tickWidth, tickHeight = self._getTickSize(cx, self.yticks,
+                                                  rotate)
+        label = unicode(labelText)
+        x = self.area.x - tickWidth - 4.0
+        y = self.area.y + 0.5 * self.area.h
+        self._renderAxisLabel(cx, tickWidth, tickHeight, label, x, y,
+                              True)
+        cx.restore()
+
     def _renderYAxis(self, cx):
         """Draws the vertical line represeting the Y axis"""
         cx.new_path()
@@ -460,6 +473,18 @@ class Chart(object):
         cx.close_path()
         cx.stroke()
 
+    def _renderXAxisLabel(self, cx, labelText):
+        cx.save()
+        rotate = self.options.axis.x.rotate
+        tickWidth, tickHeight = self._getTickSize(cx, self.xticks,
+                                                  rotate)
+        label = unicode(labelText)
+        x = self.area.x + self.area.w / 2.0
+        y = self.area.y + self.area.h + tickHeight + 4.0
+        self._renderAxisLabel(cx, tickWidth, tickHeight, label, x, y,
+                              False)
+        cx.restore()
+
     def _renderXAxis(self, cx):
         """Draws the horizontal line representing the X axis"""
         cx.new_path()
@@ -485,16 +510,7 @@ class Chart(object):
                     self._renderYTick(cx, tick)
 
             if self.options.axis.y.label:
-                cx.save()
-                rotate = self.options.axis.y.rotate
-                tickWidth, tickHeight = self._getTickSize(cx, self.yticks,
-                                                          rotate)
-                label = unicode(self.options.axis.y.label)
-                x = self.area.x - tickWidth - 4.0
-                y = self.area.y + 0.5 * self.area.h
-                self._renderAxisLabel(cx, tickWidth, tickHeight, label, x, y,
-                                      True)
-                cx.restore()
+                self._renderYAxisLabel(cx, self.options.axis.y.label)
 
             self._renderYAxis(cx)
 
@@ -505,16 +521,7 @@ class Chart(object):
                     self._renderXTick(cx, tick, fontAscent)
 
             if self.options.axis.x.label:
-                cx.save()
-                rotate = self.options.axis.x.rotate
-                tickWidth, tickHeight = self._getTickSize(cx, self.xticks,
-                                                          rotate)
-                label = unicode(self.options.axis.x.label)
-                x = self.area.x + self.area.w / 2.0
-                y = self.area.y + self.area.h + tickHeight + 4.0
-                self._renderAxisLabel(cx, tickWidth, tickHeight, label, x, y,
-                                      False)
-                cx.restore()
+                self._renderXAxisLabel(cx, self.options.axis.x.label)
 
             self._renderXAxis(cx)
 
@@ -577,7 +584,7 @@ class Chart(object):
                      width, height)
         cx.set_source_rgba(1, 1, 1, self.options.legend.opacity)
         cx.fill_preserve()
-        cx.set_line_width(self.options.stroke.width)
+        cx.set_line_width(self.options.legend.borderWidth)
         cx.set_source_rgb(*hex2rgb(self.options.legend.borderColor))
         cx.stroke()
 
@@ -680,6 +687,7 @@ DEFAULT_OPTIONS = Option(
     legend=Option(
         opacity=0.8,
         borderColor='#000000',
+        borderWidth=2,
         hide=False,
         position=Option(top=20, left=40, bottom=None, right=None),
     ),
@@ -700,6 +708,9 @@ DEFAULT_OPTIONS = Option(
         inside=False,
         fontSize=11,
         fontColor='#000000',
+        skipSmallValues=True,
+        snapToOrigin=False,
+        renderer=None
     ),
     fillOpacity=1.0,
     shouldFill=True,
